@@ -1,5 +1,6 @@
 import click
 
+from ..node.settings import settings
 from .init_agentic import init_agentic
 from .run_agentic import HTTPSERVER, REGISTRY, run_agentic
 
@@ -22,14 +23,14 @@ def init(backend, force):
 
 @click.command()
 @click.option(
-    "-M", "--mode", type=click.Choice([HTTPSERVER, REGISTRY]), default="httpserver"
+    "-M", "--mode", type=click.Choice([HTTPSERVER, REGISTRY]), default=settings.NODE_MODE
 )
-@click.option("-P", "--port", type=int, default=8000)
-@click.option("-R", "--registry", type=str, default="ws://localhost:8080")
+@click.option("-P", "--port", type=int, default=settings.HTTP_PORT)
+@click.option("-R", "--registry", type=str, default=settings.REGISTRY_URL)
 @click.option("--dev", is_flag=True, help="Run in development mode")
 def run(mode, port, registry, dev):
     """Run agentic node."""
-    click.echo("Running agenic in {} mode".format(mode))
+    click.echo("Running agentic in {} mode".format(mode))
     run_agentic(mode=mode, port=port, dev=dev, registry=registry)
 
 
