@@ -1,13 +1,17 @@
 from enum import Enum
-from typing import Callable, Dict
+from typing import Callable, Dict, Optional, Any
 from uuid import UUID, uuid4
+from abc import ABC, abstractmethod
 
 from pydantic import BaseModel, Field
 
+from agenticos.connectors.base import BaseWorkflowConfig
+
 MSG_HS_NODE = "MSG_HS_NODE"
 MSG_HS_ACK = "MSG_HS_ACK"
 MSG_TASK_REQ = "MSG_TASK_REQ"
 MSG_TASK_FIN = "MSG_TASK_FIN"
+MSG_STEP_FIN = "MSG_STEP_FIN"
 MSG_HEARTBEAT = "MSG_HEARTBEAT"
 
 
@@ -17,24 +21,28 @@ class TaskStatus(str, Enum):
     FAILED = "failed"
 
 
-class Workflow(BaseModel):
-    name: str
-    description: str
-    inputs: Dict[str, str]
-    kickoff_function: Callable[[Dict[str, str]], None] = Field(exclude=True)
-    output_function: Callable[[], str] = Field(exclude=True)
+class AgenticConfig:
+    def __init__(self, name: str, workflows: Dict[str, BaseWorkflowConfig]):
+        self.name = name
+        self.workflows = workflows
 
-
-class AgenticConfig(BaseModel):
+    id: Optional[UUID] = None
     name: str
-    workflows: Dict[str, Workflow] = {}
+    workflows: Dict[str, BaseWorkflowConfig] = {}
+
+    def model_dump(self) -> dict:
+        return {
+            "id": self.id,
+            "name": self.name,
+            "workflows": {k: v.model_dump(k) for k, v in self.workflows.items()},
+        }
 
 
 class Task(BaseModel):
     id: UUID = Field(default_factory=uuid4)
     inputs: Dict[str, str]
     status: TaskStatus = Field()
-    output: str
+    output: str | None
 
 
 class WrongFolderError(Exception):
@@ -54,14 +62,23 @@ class TaskFinishedMessage(AgenticMessage):
     type: str = MSG_TASK_FIN
     task_id: str
     status: TaskStatus
+    result: str | None
+
+
+class StepFinishedMessage(AgenticMessage):
+    type: str = MSG_STEP_FIN
+    task_id: str
+    step: int
     result: str
 
+
 class TaskRequest(BaseModel):
     workflow: str
     inputs: Dict[str, str]
     task_id: UUID = Field(default_factory=uuid4)
     node_id: str
 
+
 class AgenticTaskRequestMessage(BaseModel):
     type: str = MSG_TASK_REQ
     task: TaskRequest
